<?php

declare(strict_types=1);

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Serenity\MediaBundle\Contract;

use Serenity\CoreBundle\Shared\Doctrine\Repository\BaseRepositoryInterface;
use Serenity\MediaBundle\Entity\Attachment;

interface AttachmentRepositoryInterface extends BaseRepositoryInterface
{
    public function findOneByFilename(string $filename): ?Attachment;
}
