import "./lazyImage";
import stimulusManager from "@cpcreation/serenity-core-bundle/js/stimulusManager.js";

stimulusManager.load(require.context(
  "@symfony/stimulus-bridge/lazy-controller-loader!../controllers/auto",
  true,
  /\.(j|t)sx?$/
));
import "@cpcreation/serenity-core-bundle/js/multiselect";
import "@cpcreation/serenity-media-bundle/css/sortable.scss";
