<?php

$fileHeaderComment = <<<COMMENT
This file is part of the Serenity package.

(c) CP Creation <web@cpcreation.fr>

For the full copyright and license information, please view the LICENSE
file that was distributed with this source code.
COMMENT;

$finder = PhpCsFixer\Finder::create()
  ->in(__DIR__)
  ->exclude('config')
  ->exclude('.php-cs-fixer.php')
  ->exclude('var');

return (new PhpCsFixer\Config())
  ->setRiskyAllowed(true)
  ->setRules([
      '@Symfony' => true,
      '@Symfony:risky' => true,
      'header_comment' => ['header' => $fileHeaderComment, 'separate' => 'both'],
      'linebreak_after_opening_tag' => true,
      'mb_str_functions' => true,
      'no_php4_constructor' => true,
      'no_unreachable_default_argument_value' => true,
      'no_useless_else' => true,
      'no_useless_return' => true,
      'php_unit_strict' => true,
      'phpdoc_order' => true,
      'strict_comparison' => true,
      'strict_param' => true,
      'blank_line_between_import_groups' => false,
  ])
  ->setFinder($finder)
  ->setCacheFile(__DIR__.'/var/.php-cs-fixer.cache');
