<?php

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Serenity\MediaBundle\Contract;

use Serenity\MediaBundle\Entity\Image;
use Symfony\Component\Uid\Uuid;

interface AttachmentInterface
{
    public function getId(): Uuid;

    public function getImage(): ?Image;
}
